@@ -72,7 +72,7 @@ class Analysis(analysis_dataset.Analysis):
         self, tracer, hyper_image_sky, hyper_background_noise
     ):
 
-        return fit.ImagingFit(
+        return fit.FitImaging(
             masked_imaging=self.masked_dataset,
             tracer=tracer,
             hyper_image_sky=hyper_image_sky,
