@@ -23,11 +23,11 @@ def subplot_fit_hyper_galaxy(
 
     sub_plotter.setup_subplot(number_subplots=number_subplots, subplot_index=2)
 
-    aa.plot.fit_imaging.noise_map(fit=fit, include=include, plotter=sub_plotter)
+    aa.plot.FitImaging.noise_map(fit=fit, include=include, plotter=sub_plotter)
 
     sub_plotter.setup_subplot(number_subplots=number_subplots, subplot_index=3)
 
-    aa.plot.fit_imaging.noise_map(fit=hyper_fit, include=include, plotter=sub_plotter)
+    aa.plot.FitImaging.noise_map(fit=hyper_fit, include=include, plotter=sub_plotter)
 
     sub_plotter.setup_subplot(number_subplots=number_subplots, subplot_index=4)
 
@@ -37,11 +37,11 @@ def subplot_fit_hyper_galaxy(
 
     sub_plotter.setup_subplot(number_subplots=number_subplots, subplot_index=5)
 
-    aa.plot.fit_imaging.chi_squared_map(fit=fit, include=include, plotter=sub_plotter)
+    aa.plot.FitImaging.chi_squared_map(fit=fit, include=include, plotter=sub_plotter)
 
     sub_plotter.setup_subplot(number_subplots=number_subplots, subplot_index=6)
 
-    aa.plot.fit_imaging.chi_squared_map(
+    aa.plot.FitImaging.chi_squared_map(
         fit=hyper_fit, include=include, plotter=sub_plotter
     )
 
