@@ -9,7 +9,7 @@ from test import simulate_util
 imaging = simulate_util.load_test_imaging(
     data_type="lens_light_dev_vaucouleurs", data_resolution="lsst"
 )
-mask = al.mask.elliptical(
+mask = al.Mask.elliptical(
     shape=imaging.shape,
     pixel_scales=imaging.pixel_scales,
     major_axis_radius=3.0,
@@ -18,11 +18,11 @@ mask = al.mask.elliptical(
     centre=(0.0, 0.0),
 )
 
-# aplt.imaging.subplot(imaging=imaging, mask=mask, zoom_around_mask=True, aspect='equal')
-# aplt.imaging.subplot(imaging=imaging, mask=mask, zoom_around_mask=True, aspect='auto')
+# aplt.Imaging.subplot(imaging=imaging, mask=mask, zoom_around_mask=True, aspect='equal')
+# aplt.Imaging.subplot(imaging=imaging, mask=mask, zoom_around_mask=True, aspect='auto')
 
-# aplt.imaging.image(imaging=imaging, mask=mask, zoom_around_mask=True, aspect='square')
-# aplt.imaging.image(imaging=imaging, mask=mask, zoom_around_mask=True, aspect='equal')
+# aplt.Imaging.image(imaging=imaging, mask=mask, zoom_around_mask=True, aspect='square')
+# aplt.Imaging.image(imaging=imaging, mask=mask, zoom_around_mask=True, aspect='equal')
 
 # The lines of code below do everything we're used to, that is, setup an image and its grid, mask it, trace it
 # via a tracer, setup the rectangular mapper, etc.
@@ -44,10 +44,10 @@ source_galaxy = al.Galaxy(
     ),
 )
 
-masked_imaging = al.masked_imaging(imaging=imaging, mask=mask)
+masked_imaging = al.MaskedImaging(imaging=imaging, mask=mask)
 
 tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
-fit = al.fit(masked_dataset=masked_imaging, tracer=tracer)
+fit = al.FitImaging(masked_imaging=masked_imaging, tracer=tracer)
 
 aplt_array.fit_imaging.subplot_imaging(
     fit=fit, mask=True, include_image_plane_pix=True, aspect="auto"
