@@ -52,14 +52,14 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up", "ao"]:
         psf_shape_2d=psf_shape_2d,
     )
 
-    mask = al.mask.circular(
+    mask = al.Mask.circular(
         shape_2d=imaging.shape_2d,
         pixel_scales=imaging.pixel_scales,
         sub_size=sub_size,
         radius=radius,
     )
 
-    masked_imaging = al.masked_imaging(imaging=imaging, mask=mask)
+    masked_imaging = al.MaskedImaging(imaging=imaging, mask=mask)
 
     print("Light profile fit run times for image type " + data_resolution + "\n")
     print("Number of points = " + str(masked_imaging.grid.sub_shape_1d) + "\n")
@@ -92,7 +92,7 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up", "ao"]:
     start = time.time()
     for i in range(repeats):
         tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
-        al.fit(masked_dataset=masked_imaging, tracer=tracer)
+        al.FitImaging(masked_imaging=masked_imaging, tracer=tracer)
     diff = time.time() - start
     print("Time to perform complete fit = {}".format(diff / repeats))
 
