@@ -12,15 +12,13 @@ directory = path.dirname(path.realpath(__file__))
 
 @pytest.fixture(name="plot_path")
 def make_fit_imaging_plotter_setup():
-    return "{}/../../test_files/plotting/fit/".format(
-        os.path.dirname(os.path.realpath(__file__))
-    )
+    return "{}/files/plots/fit/".format(os.path.dirname(os.path.realpath(__file__)))
 
 
 @pytest.fixture(autouse=True)
 def set_config_path():
     conf.instance = conf.Config(
-        path.join(directory, "../test_files/plot"), path.join(directory, "output")
+        path.join(directory, "files/plotter"), path.join(directory, "output")
     )
 
 
@@ -28,7 +26,7 @@ def test__fit_quantities_are_output(
     masked_imaging_fit_x2_plane_7x7, include_all, plot_path, plot_patch
 ):
 
-    aplt.fit_imaging.image(
+    aplt.FitImaging.image(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
@@ -36,7 +34,7 @@ def test__fit_quantities_are_output(
 
     assert plot_path + "image.png" in plot_patch.paths
 
-    aplt.fit_imaging.noise_map(
+    aplt.FitImaging.noise_map(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
@@ -44,7 +42,7 @@ def test__fit_quantities_are_output(
 
     assert plot_path + "noise_map.png" in plot_patch.paths
 
-    aplt.fit_imaging.signal_to_noise_map(
+    aplt.FitImaging.signal_to_noise_map(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
@@ -52,7 +50,7 @@ def test__fit_quantities_are_output(
 
     assert plot_path + "signal_to_noise_map.png" in plot_patch.paths
 
-    aplt.fit_imaging.model_image(
+    aplt.FitImaging.model_image(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
@@ -60,7 +58,7 @@ def test__fit_quantities_are_output(
 
     assert plot_path + "model_image.png" in plot_patch.paths
 
-    aplt.fit_imaging.residual_map(
+    aplt.FitImaging.residual_map(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
@@ -68,7 +66,7 @@ def test__fit_quantities_are_output(
 
     assert plot_path + "residual_map.png" in plot_patch.paths
 
-    aplt.fit_imaging.normalized_residual_map(
+    aplt.FitImaging.normalized_residual_map(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
@@ -76,7 +74,7 @@ def test__fit_quantities_are_output(
 
     assert plot_path + "normalized_residual_map.png" in plot_patch.paths
 
-    aplt.fit_imaging.chi_squared_map(
+    aplt.FitImaging.chi_squared_map(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
@@ -89,7 +87,7 @@ def test__fit_sub_plot(
     masked_imaging_fit_x2_plane_7x7, include_all, plot_path, plot_patch
 ):
 
-    aplt.fit_imaging.subplot_fit_imaging(
+    aplt.FitImaging.subplot_fit_imaging(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
         sub_plotter=aplt.SubPlotter(output=aplt.Output(path=plot_path, format="png")),
@@ -106,7 +104,7 @@ def test__subtracted_image_of_plane_is_output(
     plot_patch,
 ):
 
-    aplt.fit_imaging.subtracted_image_of_plane(
+    aplt.FitImaging.subtracted_image_of_plane(
         fit=masked_imaging_fit_x1_plane_7x7,
         plane_index=0,
         include=include_all,
@@ -115,7 +113,7 @@ def test__subtracted_image_of_plane_is_output(
 
     assert plot_path + "subtracted_image_of_plane_0.png" in plot_patch.paths
 
-    aplt.fit_imaging.subtracted_image_of_plane(
+    aplt.FitImaging.subtracted_image_of_plane(
         fit=masked_imaging_fit_x2_plane_7x7,
         plane_index=0,
         include=include_all,
@@ -124,7 +122,7 @@ def test__subtracted_image_of_plane_is_output(
 
     assert plot_path + "subtracted_image_of_plane_0.png" in plot_patch.paths
 
-    aplt.fit_imaging.subtracted_image_of_plane(
+    aplt.FitImaging.subtracted_image_of_plane(
         fit=masked_imaging_fit_x2_plane_7x7,
         plane_index=1,
         include=include_all,
@@ -142,7 +140,7 @@ def test__model_image_of_plane_is_output(
     plot_patch,
 ):
 
-    aplt.fit_imaging.model_image_of_plane(
+    aplt.FitImaging.model_image_of_plane(
         fit=masked_imaging_fit_x1_plane_7x7,
         plane_index=0,
         include=include_all,
@@ -151,7 +149,7 @@ def test__model_image_of_plane_is_output(
 
     assert plot_path + "model_image_of_plane_0.png" in plot_patch.paths
 
-    aplt.fit_imaging.model_image_of_plane(
+    aplt.FitImaging.model_image_of_plane(
         fit=masked_imaging_fit_x2_plane_7x7,
         plane_index=0,
         include=include_all,
@@ -160,7 +158,7 @@ def test__model_image_of_plane_is_output(
 
     assert plot_path + "model_image_of_plane_0.png" in plot_patch.paths
 
-    aplt.fit_imaging.model_image_of_plane(
+    aplt.FitImaging.model_image_of_plane(
         fit=masked_imaging_fit_x2_plane_7x7,
         plane_index=1,
         include=include_all,
@@ -174,7 +172,7 @@ def test_subplot_fit_imaging_is_output(
     masked_imaging_fit_x2_plane_7x7, include_all, plot_path, plot_patch
 ):
 
-    aplt.fit_imaging.subplot_fit_imaging(
+    aplt.FitImaging.subplot_fit_imaging(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
         sub_plotter=aplt.SubPlotter(output=aplt.Output(plot_path, format="png")),
@@ -191,7 +189,7 @@ def test__subplot_of_plane(
     plot_patch,
 ):
 
-    aplt.fit_imaging.subplot_of_plane(
+    aplt.FitImaging.subplot_of_plane(
         fit=masked_imaging_fit_x1_plane_7x7,
         plane_index=0,
         include=include_all,
@@ -200,7 +198,7 @@ def test__subplot_of_plane(
 
     assert plot_path + "subplot_of_plane_0.png" in plot_patch.paths
 
-    aplt.fit_imaging.subplot_of_plane(
+    aplt.FitImaging.subplot_of_plane(
         fit=masked_imaging_fit_x2_plane_7x7,
         plane_index=0,
         include=include_all,
@@ -209,7 +207,7 @@ def test__subplot_of_plane(
 
     assert plot_path + "subplot_of_plane_0.png" in plot_patch.paths
 
-    aplt.fit_imaging.subplot_of_plane(
+    aplt.FitImaging.subplot_of_plane(
         fit=masked_imaging_fit_x2_plane_7x7,
         plane_index=1,
         include=include_all,
@@ -218,7 +216,7 @@ def test__subplot_of_plane(
 
     assert plot_path + "subplot_of_plane_1.png" in plot_patch.paths
 
-    aplt.fit_imaging.subplots_of_all_planes(
+    aplt.FitImaging.subplots_of_all_planes(
         fit=masked_imaging_fit_x1_plane_7x7,
         include=include_all,
         sub_plotter=aplt.SubPlotter(output=aplt.Output(plot_path, format="png")),
@@ -226,7 +224,7 @@ def test__subplot_of_plane(
 
     assert plot_path + "subplot_of_plane_0.png" in plot_patch.paths
 
-    aplt.fit_imaging.subplots_of_all_planes(
+    aplt.FitImaging.subplots_of_all_planes(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
         sub_plotter=aplt.SubPlotter(output=aplt.Output(plot_path, format="png")),
@@ -244,7 +242,7 @@ def test__fit_individuals__source_and_lens__dependent_on_input(
     plot_patch,
 ):
 
-    aplt.fit_imaging.individuals(
+    aplt.FitImaging.individuals(
         fit=masked_imaging_fit_x1_plane_7x7,
         plot_image=True,
         plot_noise_map=False,
@@ -278,7 +276,7 @@ def test__fit_individuals__source_and_lens__dependent_on_input(
 
     assert plot_path + "plane_image_of_plane_0.png" in plot_patch.paths
 
-    aplt.fit_imaging.individuals(
+    aplt.FitImaging.individuals(
         fit=masked_imaging_fit_x2_plane_7x7,
         plot_image=True,
         plot_noise_map=False,
